summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/pdf/poppler-qt/poppler-page-transition.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
commite69e8b1d09fb579316595b4e6a850e717358a8b1 (patch)
treea24fc20865f65772f530d16177520190594ffdd2 /kfile-plugins/pdf/poppler-qt/poppler-page-transition.h
parenteecec9afb81fdebb0f22e9da22635874c403f854 (diff)
downloadtdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.tar.gz
tdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.zip
TQt4 port kdegraphics
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1237557 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kfile-plugins/pdf/poppler-qt/poppler-page-transition.h')
-rw-r--r--kfile-plugins/pdf/poppler-qt/poppler-page-transition.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kfile-plugins/pdf/poppler-qt/poppler-page-transition.h b/kfile-plugins/pdf/poppler-qt/poppler-page-transition.h
index 53002ff9..f33a014c 100644
--- a/kfile-plugins/pdf/poppler-qt/poppler-page-transition.h
+++ b/kfile-plugins/pdf/poppler-qt/poppler-page-transition.h
@@ -60,7 +60,7 @@ class PageTransition {
Fade
};
/** \brief alignment of the transition effect that shall be used
*/
// if changed remember to keep in sync with PageTransition.h enum
enum Alignment {
@@ -114,7 +114,7 @@ class PageTransition {
/**
\brief Get dimension in which the transition effect occurs.
*/
- Alignment alignment() const;
+ Alignment tqalignment() const;
/**
\brief Get direction of motion of the transition effect.
@@ -60,7 +60,7 @@ class PageTransition {
Fade
};
- /** \brief alignment of the transition effect that shall be used
+ /** \brief tqalignment of the transition effect that shall be used
*/
// if changed remember to keep in sync with PageTransition.h enum